antares.apps.accounting.exceptions package — Antares 0.0.2 documentation

# antares.apps.accounting.exceptions package

## Submodules

## antares.apps.accounting.exceptions.missing_account_header_information_exception module

Copyright 2013-2017 SurferTank Inc.

Original version by Leonardo Belen<leobelen@gmail.com>

exception `antares.apps.accounting.exceptions.missing_account_header_information_exception.` `MissingAccountHeaderInformationException`(value)

  Bases: `Exception`

  Indicates a problem exists with the header information of the current account.

## antares.apps.accounting.exceptions.negative_amount_exception module

Copyright 2013-2017 SurferTank Inc.

Original version by Leonardo Belen<leobelen@gmail.com>

exception `antares.apps.accounting.exceptions.negative_amount_exception.` `NegativeAmountException`(value)

  Bases: `Exception`

  Indicates an unauthorized negative amount was entered into the current account.

## Module contents